@@ -50,7 +50,7 @@ class TFDiceLoss(tf.keras.losses.Loss):
         self.from_logits = from_logits
         self.log_loss = log_loss
 
-    def call(self, y_pred, y_true):
+    def call(self, y_true, y_pred):
         """
         :param y_pred: (N, *, C)
         :param y_true: (N, *)
@@ -115,7 +115,7 @@ if __name__ == '__main__':
     true = tf.convert_to_tensor([[2, 1, 0, 2]])
 
     dice = TFDiceLoss("multiclass", from_logits=True)
-    loss = dice(pred, true)
+    loss = dice(true, pred)
     assert float(loss) == 0.5519775748252869
     print(round(float(loss), 7) , '== 0.5519775748252869')
 
@@ -125,7 +125,7 @@ if __name__ == '__main__':
     true = tf.convert_to_tensor([0, 1, 0, 1])
     true = tf.reshape(true, [1, 2, 2])
     dice = TFDiceLoss("binary", from_logits=True)
-    loss = dice(pred, true)
+    loss = dice(true, pred)
     print(round(float(loss), 7), '== 0.46044689416885376')
 
     print("Binary Log loss")
@@ -134,5 +134,5 @@ if __name__ == '__main__':
     true = tf.convert_to_tensor([0, 1, 0, 1])
     true = tf.reshape(true, [1, 2, 2])
     dice = TFDiceLoss("binary", from_logits=True, log_loss=True)
-    loss = dice(pred, true)
+    loss = dice(true, pred)
     print(round(float(loss), 7), '== 0.6170140504837036')
\ No newline at end of file
