@@ -1,4 +1,6 @@
 from .unet.unet import UNet
 from .unet.tfunet import TFUNet
+from .resunet.resunet import ResUNet
+from .resunet.tfresunet import TFResUNet
 from .unet2plus.unet2plus import UNet2plus
 from .unet2plus.tfunet2plus import TFUNet2plus
